
import React from 'react';
import Container from 'react-bootstrap/Container';
import Col from 'react-bootstrap/Col';
import Row from 'react-bootstrap/Row';
import JobCard, { JobCardPlaceholder } from './JobCard';
import { partition } from '../../utils';
import { JobListProps } from './types';

export type Props = {
  heading: string,
} & JobListProps

const defaultProps = {
  entriesPerRow: 2,
  currentHeading: 'Currently',
}

export function JobsCardsPlaceholder() {
  return <Container>
    <Row><Col><JobCardPlaceholder /></Col></Row>
    <Row><Col><JobCardPlaceholder /></Col></Row>
  </Container>
}

export default function JobsCards(props: JobListProps) {
  const {jobs} = props
  const config = {...defaultProps, ...props}
  return (
    <Container>
      {jobs.current && (
      <Row>
        <Col>
          <JobCard heading={config.currentHeading} {...jobs.current} />
        </Col>
      </Row>
      )}
      {partition(jobs.previous, config.entriesPerRow).map((jobs, index) => (
      <Row key={index}>
        {(jobs.map((job, subindex) => (
        <Col key={index + '_' + subindex}>
          <JobCard {...job} />
        </Col>
        )))}
      </Row>
      ))}
    </Container>
  )
}
